@@ -54,7 +54,8 @@ class ManageFiles():
             # headers: preset headers, stream = True for stream upload
             with file_request.post(url, file, headers=headers, stream=True) as req:
                 # Retrun error if happened during HTTP request
-                req.raise_for_status()
+                if req.raise_for_status():
+                    print(req)
         # Closing post request after finishing upload
         file_request.close()
         # Return success message
